import { Component, ContentChildren, ElementRef, Input, QueryList, ViewChild } from '@angular/core';
import { IonMarker } from './ion-marker';
import { NativeGoogleMapsProvider } from '../providers/native-google-maps';
import { Platform } from 'ionic-angular';
var IonMaps = (function () {
    function IonMaps(platform, mapsCtrl) {
        this.platform = platform;
        this.mapsCtrl = mapsCtrl;
        /**
           * The height of the map. Default value is '100%'.
           */
        this.height = '100%';
        /**
           * The width of the map. Default value is '100%'.
           */
        this.width = '100%';
        /**
           * The zoom of the map. Default value is 16.
           */
        this.zoom = 15;
    }
    IonMaps.prototype.ngAfterContentInit = function () {
        var _this = this;
        // After content is rendered, load markers, if any
        var markers = this.markers.toArray();
        this.platform.ready().then(function (_) {
            // Then, generate the map itself
            // Then, generate the map itself
            _this.mapsCtrl.create(_this, markers);
        });
    };
    IonMaps.prototype.centerToGeolocation = function () {
        return this.mapsCtrl.centerToGeolocation();
    };
    IonMaps.decorators = [
        { type: Component, args: [{
                    selector: 'ion-maps',
                    template: "\n    <div #map [style.height]=\"height\" [style.width]=\"width\"></div>\n    <ng-content></ng-content>",
                    styles: [
                        "ion-maps {\n      .geolocation {\n\n        $box-shadow: 0px 0px 2px  rgba(0,0,0,0.6);\n        $icon-size: 20px;\n        $icon-radius: 100%;\n        $color-icon-outer: #65a3ff;\n        $color-icon-inner: rgba(101, 163, 255, 0.4);\n\n        z-index:2;\n        position:absolute;\n        width:$icon-size;\n        height:$icon-size;\n        border: 2px solid white;\n        border-radius:$icon-radius;\n        background:$color-icon-outer;\n        box-shadow: $box-shadow;\n        -moz-box-shadow: $box-shadow;\n        -webkit-box-shadow: $box-shadow;\n        -o-box-shadow: $box-shadow;\n\n        .geolocation-inner {\n          top: -2px;\n          left: -2px;\n          z-index:1;\n          position: relative;\n          width:$icon-size;\n          height:$icon-size;\n          background:$color-icon-inner;\n          border: 1px solid rgba(101, 163, 255, 0.5);\n          border-radius:$icon-radius;\n          animation: 1.6s pulse infinite linear;\n        }\n      }\n\n      @keyframes pulse {\n        from  { transform: scale(1) }\n        to {\n          transform: scale(3);\n          opacity:0;\n        }\n      }\n    }"
                    ]
                },] },
    ];
    /** @nocollapse */
    IonMaps.ctorParameters = function () { return [
        { type: Platform, },
        { type: NativeGoogleMapsProvider, },
    ]; };
    IonMaps.propDecorators = {
        "lat": [{ type: Input },],
        "lng": [{ type: Input },],
        "height": [{ type: Input },],
        "width": [{ type: Input },],
        "zoom": [{ type: Input },],
        "tilt": [{ type: Input },],
        "showGeolocation": [{ type: Input },],
        "mapStyle": [{ type: Input },],
        "element": [{ type: ViewChild, args: ['map',] },],
        "markers": [{ type: ContentChildren, args: [IonMarker,] },],
    };
    return IonMaps;
}());
export { IonMaps };
//# sourceMappingURL=ion-maps.js.map