export declare class IonMarker {
    /**
     * Only works with static maps.
     * The address of the marker.
     * Ignores lat lng if passed.
     */
    address: string;
    /**
     * The latitude position of the marker.
     */
    lat: number;
    /**
     * The longitude position of the marker.
     */
    lng: number;
    /**
     * The title of the marker.
     */
    title: string;
    /**
     * Only works on javascript maps.
     * HTML to compose a custom marker element.
     */
    customHTML: string;
    /**
     * Only works on javascript maps.
     * Class or classes to be added on the parent div of a customHTML marker element.
     */
    parentClass: string;
    /**
     * Only works on javascript maps.
     * The label (a single uppercase character) for the marker.
     */
    label: string;
    /**
     * Only works on static maps.
     * The color of the marker.
     * Accepted format: 0xRRGGBB or one of these: ['yellow', 'red', 'green', 'blue', 'purple', 'orange', 'green']
     */
    color: string;
    /**
     * If true, the marker can be dragged. Default value is false.
     */
    draggable: boolean;
    /**
     * If true, the marker will have a DROP animation on the screen. Default value is false.
     */
    animated: boolean;
    /**
     * Icon (the URL of the image) for the foreground.
     */
    iconUrl: string;
    /**
     * If true, the marker is visible
     */
    visible: boolean;
    /**
     * Whether to automatically open the child info window when the marker is clicked.
     */
    openInfoWindow: boolean;
    /**
     * Only works on javascript maps.
     * The marker's opacity between 0.0 and 1.0.
     */
    opacity: number;
    /**
     * All markers are displayed on the map in order of their zIndex, with higher values displaying in
     * front of markers with lower values. By default, markers are displayed according to their
     * vertical position on screen, with lower markers appearing in front of markers further up the
     * screen.
     */
    zIndex: number;
}
