import { InjectionToken, NgModule } from '@angular/core';
import { GoogleMaps } from '@ionic-native/google-maps';
import { Geolocation } from '@ionic-native/geolocation';
import { IonMaps } from './components/ion-maps';
import { IonStaticMapsComponent } from './components/ion-static-maps';
import { IonMarker } from './components/ion-marker';
import { JavascriptGoogleMapsProvider } from './providers/javascript-google-maps';
import { NativeGoogleMapsProvider } from './providers/native-google-maps';
/**
 * Checks if the supplied document url is a one used by
 * cordova to load the app.
 *
 * @param {string} docUrl the current document url.
 */
export function isCordova(docUrl) {
    // if running `ionic cordova run PLATFORM --device --livereload`
    // it loads from the local ip of the host.
    var DEFAULT_LIVERELOAD_URL = new RegExp(/^http:\/\/\d+\.\d+\.\d+\.\d+\:810[0-9]/);
    // cordova by default loads app from file
    var DEFAULT_WEBVIEW_URL = 'file:///';
    // using ionic wk-webview creates a local webserver on the device to serve the app.
    var WK_WEBVIEW_URL = 'http://localhost:8080/var/containers/Bundle/Application';
    return docUrl.match(DEFAULT_LIVERELOAD_URL)
        || docUrl.startsWith(DEFAULT_WEBVIEW_URL)
        || docUrl.startsWith(WK_WEBVIEW_URL);
}
// Injection Token to pass document.url to angular contexts
var DOCUMENT_URL = new InjectionToken('document-url');
// returns the document url -- necessary for AoT compilation
export function documentUrlFactory() {
    return document.URL;
}
// Need factories for every provider that
// changes based on app runtime context
export function gmapsProviderFactory(docUrl, geolocation, gmaps) {
    return isCordova(docUrl)
        ? new NativeGoogleMapsProvider(geolocation, gmaps)
        : new JavascriptGoogleMapsProvider(geolocation);
}
export var COMPONENTS = [
    IonMaps,
    IonStaticMapsComponent,
    IonMarker,
];
var IonMapsModule = (function () {
    function IonMapsModule() {
    }
    IonMapsModule.forRoot = function (config) {
        return {
            ngModule: IonMapsModule,
            providers: [
                {
                    provide: DOCUMENT_URL,
                    useFactory: documentUrlFactory,
                },
                {
                    provide: NativeGoogleMapsProvider,
                    useFactory: gmapsProviderFactory,
                    deps: [DOCUMENT_URL, Geolocation, GoogleMaps],
                },
            ],
        };
    };
    IonMapsModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [COMPONENTS],
                    exports: [COMPONENTS]
                },] },
    ];
    /** @nocollapse */
    IonMapsModule.ctorParameters = function () { return []; };
    return IonMapsModule;
}());
export { IonMapsModule };
//# sourceMappingURL=ion-maps.module.js.map