var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { Injectable } from '@angular/core';
import { Geolocation } from '@ionic-native/geolocation';
import { IonMapStyles } from '../config/maps.styles';
import { GoogleMapsLoader } from './google-maps.loader';
var JavascriptGoogleMapsProvider = (function () {
    function JavascriptGoogleMapsProvider(geolocation) {
        this.geolocation = geolocation;
        this.markers = new Array();
    }
    // Note: Call this method on ngAfterViewInit
    // Note: Call this method on ngAfterViewInit
    JavascriptGoogleMapsProvider.prototype.create = 
    // Note: Call this method on ngAfterViewInit
    function (map, markers) {
        var _this = this;
        if (markers === void 0) { markers = []; }
        return GoogleMapsLoader
            .load()
            .then(function (_) { return _this.initMap(map); })
            .then(function (_) { return _this.setupCustomHTMLMarker(); })
            .then(function (_) { return _this.addGeolocationPin(map.showGeolocation); })
            .then(function (_) { return _this.loadMarkers(markers); });
    };
    JavascriptGoogleMapsProvider.prototype.initMap = function (map) {
        var lat = map.lat, lng = map.lng, zoom = map.zoom;
        var mapOptions = {
            center: new google.maps.LatLng(lat, lng),
            zoom: zoom,
            mapTypeId: google.maps.MapTypeId.ROADMAP,
            disableDefaultUI: true,
            styles: this.parseMapStyles(map),
        };
        this.map = new google.maps.Map(map.element.nativeElement, mapOptions);
        return Promise.resolve(this.map);
    };
    JavascriptGoogleMapsProvider.prototype.setupCustomHTMLMarker = function () {
        this.USGSOverlay = (function (_super) {
            __extends(class_1, _super);
            function class_1(latlng, map, parentclass, html, isPointer, div) {
                var _this = _super.call(this) || this;
                _this.latlng = latlng;
                _this.map = map;
                _this.parentclass = parentclass;
                _this.html = html;
                _this.isPointer = isPointer;
                _this.div = div;
                _this.setMap(map);
                return _this;
            }
            class_1.prototype.onAdd = function () {
                // Create the parent element marker
                this.div = document.createElement('div');
                // Set any classes defined for the parent element
                this.div.className = this.parentclass;
                // Parent element must be set to absolute so it's positioned correctly on the map
                this.div.style.position = 'absolute';
                // If the user wants the cursor to become a pointer when hovered
                if (this.isPointer) {
                    this.div.style.cursor = 'pointer';
                }
                // Add the user defined HTML string to the parent div marker...
                this.div.innerHTML = this.html;
                // The parent div gets added to the overlay image
                var panes = this.getPanes();
                panes.overlayImage.appendChild(this.div);
            };
            class_1.prototype.draw = function () {
                var _this = this;
                // We make sure that the marker becomes clickable in case the user wants to do something on click
                google.maps.event.addDomListener(this.div, 'click', function (event) {
                    google.maps.event.trigger(_this, 'click', event);
                });
                // We create the actual position of the marker on the map, this is where the marker gets added
                var point = this.getProjection().fromLatLngToDivPixel(this.latlng);
                if (point) {
                    this.div.style.left = point.x + "px";
                    this.div.style.top = point.y + "px";
                }
            };
            return class_1;
        }(google.maps.OverlayView));
    };
    JavascriptGoogleMapsProvider.prototype.addGeolocationPin = function (showGeolocation) {
        var _this = this;
        if (showGeolocation == 'true') {
            return this.getGeolocationPosition().then(function (position) {
                var geolocationHTML = "<div class='geolocation-inner'></div>";
                new _this.USGSOverlay(position, _this.map, 'geolocation', geolocationHTML, false);
            });
        }
    };
    JavascriptGoogleMapsProvider.prototype.parseMapStyles = function (map) {
        return typeof map.mapStyle === 'string'
            ? IonMapStyles[map.mapStyle.toLowerCase()]
            : map.mapStyle;
    };
    JavascriptGoogleMapsProvider.prototype.loadMarkers = function (markers) {
        var _this = this;
        markers.map(function (marker) { return marker.customHTML ? _this.addHtmlMarker(marker) : _this.addMarker(marker); });
    };
    JavascriptGoogleMapsProvider.prototype.centerToGeolocation = function () {
        var _this = this;
        return this.getGeolocationPosition()
            .then(function (position) { return _this.centerToPosition(position); });
    };
    JavascriptGoogleMapsProvider.prototype.getGeolocationPosition = function () {
        return this.geolocation.getCurrentPosition()
            .then(function (position) { return new google.maps.LatLng(position.coords.latitude, position.coords.longitude); });
    };
    JavascriptGoogleMapsProvider.prototype.centerToPosition = function (latLng) {
        return Promise.resolve(this.map.panTo(latLng));
    };
    JavascriptGoogleMapsProvider.prototype.addHtmlMarker = function (marker) {
        var lat = marker.lat, lng = marker.lng, customHTML = marker.customHTML, parentClass = marker.parentClass;
        new this.USGSOverlay(new google.maps.LatLng(lat, lng), this.map, parentClass, customHTML, true);
    };
    JavascriptGoogleMapsProvider.prototype.addMarker = function (marker) {
        var _this = this;
        var lat = marker.lat, lng = marker.lng, label = marker.label, iconUrl = marker.iconUrl, title = marker.title, animated = marker.animated, draggable = marker.draggable, opacity = marker.opacity, visible = marker.visible, zIndex = marker.zIndex;
        var mapMarker = new google.maps.Marker({
            label: label,
            title: title,
            opacity: opacity,
            visible: visible,
            zIndex: zIndex,
            icon: iconUrl,
            draggable: draggable,
            position: new google.maps.LatLng(lat, lng),
            map: this.map,
            animation: animated ? google.maps.Animation.DROP : null,
        });
        if (title) {
            var infoWindow_1 = new google.maps.InfoWindow({ content: title });
            mapMarker.addListener('click', function (_) { return infoWindow_1.open(_this.map, mapMarker); });
            // infoWindow.addListener('click', _ => infoClickCallback);
        }
        this.markers.push(mapMarker);
        return Promise.resolve(mapMarker);
    };
    JavascriptGoogleMapsProvider.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    JavascriptGoogleMapsProvider.ctorParameters = function () { return [
        null,
        null,
        null,
        null,
        null,
        null,
    ]; };
    return JavascriptGoogleMapsProvider;
}());
export { JavascriptGoogleMapsProvider };
//# sourceMappingURL=javascript-google-maps.js.map