import { Injectable } from '@angular/core';
import { GoogleMaps, GoogleMapsAnimation, GoogleMapsEvent, LatLng, } from '@ionic-native/google-maps';
import { Geolocation } from '@ionic-native/geolocation';
import { IonMapStyles } from '../config/maps.styles';
var NativeGoogleMapsProvider = (function () {
    function NativeGoogleMapsProvider(geolocation, googleMaps) {
        this.geolocation = geolocation;
        this.googleMaps = googleMaps;
    }
    // Note: Call this method on ngAfterViewInit
    // Note: Call this method on ngAfterViewInit
    NativeGoogleMapsProvider.prototype.create = 
    // Note: Call this method on ngAfterViewInit
    function (map, markers) {
        var _this = this;
        if (markers === void 0) { markers = []; }
        var lat = map.lat, lng = map.lng, zoom = map.zoom, tilt = map.tilt;
        var options = {
            camera: {
                target: {
                    lat: map.lat,
                    lng: map.lng
                },
                zoom: map.zoom,
                tilt: map.tilt
            },
            controls: {
                compass: false,
                myLocationButton: true,
                zoom: true
            },
            styles: this.parseMapStyles(map)
        };
        this.map = this.googleMaps.create(map.element.nativeElement, options);
        return this.map.one(GoogleMapsEvent.MAP_READY)
            .then(function (_) { return _this.loadMarkers(markers); });
    };
    NativeGoogleMapsProvider.prototype.parseMapStyles = function (map) {
        return typeof map.mapStyle === 'string'
            ? IonMapStyles[map.mapStyle.toLowerCase()]
            : map.mapStyle;
    };
    NativeGoogleMapsProvider.prototype.loadMarkers = function (markers) {
        var _this = this;
        markers.map(function (marker) { return _this.addMarker(marker); });
    };
    NativeGoogleMapsProvider.prototype.centerToGeolocation = function () {
        var _this = this;
        return this.getGeolocationPosition()
            .then(function (position) { return _this.centerToPosition(position); });
    };
    NativeGoogleMapsProvider.prototype.getGeolocationPosition = function () {
        return this.geolocation.getCurrentPosition()
            .then(function (position) { return new LatLng(position.coords.latitude, position.coords.longitude); });
    };
    NativeGoogleMapsProvider.prototype.addGeolocationPin = function () {
        // No need to do anything, native already handles that.
    };
    NativeGoogleMapsProvider.prototype.centerToPosition = function (latLng, zoom, tilt) {
        var cameraPosition = {
            target: latLng,
            zoom: zoom || 15,
            tilt: tilt || 10
        };
        return this.map.moveCamera(cameraPosition);
    };
    NativeGoogleMapsProvider.prototype.addMarker = function (marker) {
        var lat = marker.lat, lng = marker.lng, iconUrl = marker.iconUrl, title = marker.title, animated = marker.animated, draggable = marker.draggable, visible = marker.visible, zIndex = marker.zIndex;
        var markerOptions = {
            position: new LatLng(lat, lng),
            title: title,
            icon: iconUrl,
            animation: animated ? GoogleMapsAnimation.DROP : null,
            zIndex: zIndex,
            draggable: draggable,
            visible: visible
        };
        return this.map.addMarker(markerOptions);
    };
    NativeGoogleMapsProvider.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    NativeGoogleMapsProvider.ctorParameters = function () { return [
        { type: Geolocation, },
        { type: GoogleMaps, },
    ]; };
    return NativeGoogleMapsProvider;
}());
export { NativeGoogleMapsProvider };
//# sourceMappingURL=native-google-maps.js.map